@@ -1,10 +1,17 @@
 package Kwiki::Registry;
 use strict;
 use warnings;
-use Spoon::Registry '-base';
+use Spoon::Registry '-Base';
 
 const registry_directory => './plugin';
 
+sub add {
+    my ($key, $value) = @_;
+    return super
+      unless $key eq 'preference' and @_ == 2;
+    super($key, $value->id, object => $value);
+}
+
 1;
 
 __DATA__
